@@ -31,18 +31,19 @@ def config_to_client(config=None):
 
 
 class InfluxdbReader(object):
-    __slots__ = ('path', 'client')
+    __slots__ = ('client', 'path', 'logger')
 
-    def __init__(self, client, path):
+    def __init__(self, client, path, logger):
         self.client = client
         self.path = path
+        self.logger = logger
 
     def fetch(self, start_time, end_time):
         data = self.client.query("select time, value from %s where time > %ds and time < %ds order asc" % (self.path, start_time, end_time))
         datapoints = []
         start = 0
         end = 0
-        step = 0
+        step = 10
         try:
             points = data[0]['points']
             start = points[0][0]
@@ -52,6 +53,8 @@ class InfluxdbReader(object):
         except Exception:
             pass
         time_info = start, end, step
+        self.logger.debug("influx REQUESTED RANGE for %s: %d to %d" % (self.path, start_time, end_time))
+        self.logger.debug("influx RETURNED  RANGE for %s: %d to %d" % (self.path, start, end))
         return time_info, datapoints
 
     def get_intervals(self):
@@ -75,7 +78,7 @@ class InfluxdbFinder(object):
         # from graphite_api.app import app
         # self.logger = app.logger
         logging.basicConfig()
-        self.logger = logging.getLogger("FUCK")
+        self.logger = logging.getLogger("graphite-influxdb")
         self.logger.setLevel(logging.DEBUG)
 
     def find_nodes(self, query):
@@ -92,7 +95,7 @@ class InfluxdbFinder(object):
         # for leaf "a.b.c" we should yield branches "a" and "a.b"
         for s in series:
             self.logger.info("leaf %s" % s)
-            yield LeafNode(s, InfluxdbReader(self.client, s))
+            yield LeafNode(s, InfluxdbReader(self.client, s, self.logger))
             branch = s.rpartition('.')[0]
             while branch != '' and branch not in seen_branches:
                 self.logger.info("branch %s" % branch)
